usage()
{
    cat <<EOF
usage: $(basename $0) -i IMAGE

Run desktop default scenario using default parameters

options:
    -h               Show this help and exit
    -i IMAGE         Path/URL to image to be used
    -n NAME          Machine name to provision
EOF
}

parse_args()
{
    while getopts :i:n: OPTION; do
        case $OPTION in
            i)
                IMAGE=$OPTARG
                shift 2
                ;;
            n)
                NAME=$OPTARG
                shift 2
                ;;
            ?)
                usage
                exit
                ;;
        esac
    done

    if [ -z "$IMAGE" ]; then
        usage
        exit
    fi

    if [ -z "$PRESEED" ]; then
        echo "PRESEED environment variable not found"
        exit
    fi

    if [ -z "$RUNLIST" ]; then
        echo "RUNLIST environment variable not found"
        exit
    fi

    CMD="run_utah_tests.py -i $IMAGE -p $PRESEED $RUNLIST -f /var/log/installer -n --poweroff"

    [ -n "$NAME" ] && CMD="$CMD --name $NAME"

    [ -n "$BOOT_ARGS" ] && CMD="$CMD -b $BOOT_ARGS"

    [ -n "$EXTRA_ARGS" ] && CMD="$CMD $EXTRA_ARGS"
}
