#!/usr/bin/python3
#
# Copyright (C) 2023, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Target system should use the right locale and timezone"""

import logging
import os
import unittest


class SystemLocalizedTest(unittest.TestCase):
    TIMEZONE_FILE = '/etc/timezone'
    RIGHT_TIMEZONE = 'America/Chicago'
    RIGHT_LANG = 'fr_FR.UTF-8'

    def test_system_localized(self):
        """Test timezone settings."""
        logging.info('Reading {!r} file...'.format(self.TIMEZONE_FILE))
        with open(self.TIMEZONE_FILE) as f:
            timezone = f.read().rstrip()

        logging.info('Checking that timezone is ({!r})'
                     .format(self.RIGHT_TIMEZONE))
        self.assertEqual(timezone, self.RIGHT_TIMEZONE,
                        'Timezone not matching what expected')

        """Test locale settings."""
        logging.info('Getting system locale')
        lang = os.getenv('LANG')
        logging.info('Checking that LANG is ({!r})'
                     .format(self.RIGHT_LANG))
        self.assertEqual(lang, self.RIGHT_LANG,
                        'LANG not matching what expected')

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
